@@ -9,7 +9,7 @@ package Vote::Count;
 use namespace::autoclean;
 use Moose;
 
-# use Data::Printer;
+# use Data::Dumper;
 use Time::Piece;
 use Path::Tiny;
 use Vote::Count::Matrix;
@@ -17,14 +17,14 @@ use Storable 3.15 'dclone';
 
 no warnings 'experimental';
 
-our $VERSION='1.01';
+our $VERSION='1.02';
 
 =head1 NAME
 
 Vote::Count
 
 
-=head1 VERSION 1.01
+=head1 VERSION 1.02
 
 =cut
 
@@ -110,7 +110,8 @@ sub BUILD {
 }
 
 # load the roles providing the underlying ops.
-with 'Vote::Count::Approval',
+with 
+  'Vote::Count::Approval',
   'Vote::Count::Borda',
   'Vote::Count::Floor',
   'Vote::Count::IRV',
@@ -124,6 +125,25 @@ sub VotesCast ( $self ) {
   return $self->BallotSet()->{'votescast'};
 }
 
+sub VotesActive ( $self ) {
+  unless ( $self->BallotSet()->{'options'}{'rcv'} ) {
+    die "VotesActive Method only supports rcv"
+  }
+  my $set         = $self->BallotSet();
+  my $active      = $self->Active();
+  my $activeCount = 0;
+LOOPVOTESACTIVE:
+    for my $B ( values $set->{ballots}->%* ) {
+        for my $V ( $B->{'votes'}->@* ) {
+            if ( defined $active->{$V} ) {
+                $activeCount += $B->{'count'};
+                next LOOPVOTESACTIVE;
+            }
+        }
+    }
+  return $activeCount;
+}
+
 sub BallotSetType ( $self ) {
   if ( $self->BallotSet()->{'options'}{'rcv'} ) {
     return 'rcv';
@@ -150,11 +170,6 @@ __PACKAGE__->meta->make_immutable;
 
 Provides a Toolkit for implementing multiple voting systems, allowing a wide range of method options. This library allows the creation of election resolution methods matching a set of Election Rules that are written in an organization's governing rules, and not requiring the bylaws to specify the rules of the software that will be used for the election, especially important given that many of the other libraries available do not provide a bylaws compatible explanation of their process.
 
-This is also extremely useful to researchers who may want to study multiple methods and variations of methods.
-
-
-=head1 Synopsis
-
   use 5.022; # Minimum Perl, or any later Perl.
   use feature qw /postderef signatures/;
 
@@ -182,6 +197,7 @@ This is also extremely useful to researchers who may want to study multiple meth
   my $Winner = $CondorcetElection->RunCondorcetDropping( $SmithSet )->{'winner'};
 
   # Create an object for IRV, use the same Floor as Condorcet
+
   my $IRVElection = Vote::Count->new(
     'BallotSet' => $ballotset,
     'Active' => $ChoicesAfterFloor );
@@ -201,10 +217,10 @@ This is also extremely useful to researchers who may want to study multiple meth
   # Now print the logs and winning information.
   say $CondorcetElection->logv();
   say $IRVElection->logv();
-  say 'B<>B<>B<>B<>**';
+  say '*'x60;
   say "Plurality Winner: $PluralityWinner->{'winner'}";
   say "IRV Winner: $IRVResult->{'winner'}";
-  say "Winner: $Winner";
+  say "Condorcet Winner: $Winner";
 
 
 =head1 Overview
@@ -212,7 +228,7 @@ This is also extremely useful to researchers who may want to study multiple meth
 
 =head2 Brief Review of Voting Methods
 
-Several alternatives have been proposed to the simple vote for a single choice method that has been used in most elections for a single member. In addition a number of different methods have been used for multiple members. For alternative single member voting, the three common alternatives are I<Approval> (voters indicate all choices that they approve of), I<Ranked Choice> (Voters rank the choices), and I<Score> also known as I<Range> (A Ranked Choice Ballot where the number of rankings is limited but voters may rank more than 1 choice at each rank).
+Several alternatives have been proposed to the simple vote for a single choice method that has been used in most elections for a single member. In addition a number of different methods have been used for multiple members. For alternative single member voting, the three common alternatives are I<Approval> (voters indicate all choices that they approve of), I<Ranked Choice> (Voters rank the choices), and I<Score> also known as I<Range> (voters give choices a score according to a scale).
 
 I<Vote for One> ballots may be resolved by one of two methods: I<Majority> and I<Plurality>. Majority vote requires a majority of votes to win (but frequently produces no winner), and Plurality which selects the choice with the most votes.
 
@@ -376,15 +392,15 @@ When a Condorcet Winner is present Consistency is very high. When there is no Co
 
 =head3 Range (Score) Voting Systems
 
-Most Methods for Ranked Choice Ballots can be used for Range Ballots. Incentive for Strategic Voting
+Most Methods for Ranked Choice Ballots can be used for Range Ballots.
 
 Score Voting proposals typically implement I<Borda Count>, with a fixed depth of choices. I<STAR>, creates a virtual runoff between the top two I<Borda Count> Choices.
 
-Advocates claim that this Ballot Style is a better expression of voter preference. Where it shows a clear advantage is in allowing Voters to directly mitigate Later Harm by ranking a strongly favored choice with the highest score and weaker choices with the lowest.
+Advocates claim that this Ballot Style is a better expression of voter preference. Where it shows a clear advantage is in allowing Voters to directly mitigate Later Harm by ranking a strongly favored choice with the highest score and weaker choices with the lowest. The downside to this strategy is that the voter is giving little help to later choices reaching the automatic runoff. Given a case with two roughly equal main factions, where one faction give strong support to all of its options, and the other faction's supporters give weak support to all later choices; the runoff will be between the two best choices of the first faction, even if the choices of the second faction all defeat any of the first's choices in pairwise comparison.
 
-The Range Ballot resolves the Borda weighting problem and allows the voter to manage the later harm effect, so it is clearly the better choice for Borda. Condorcet and IRV can resolve Range Ballots, but ignore the extra information and would prefer strict ordinality (not allowing equal ranking).
+The Range Ballot resolves the Borda weighting problem and allows the voter to manage the later harm effect, so it is clearly a better choice than Borda. Condorcet and IRV can resolve Range Ballots, but ignore the extra information and would prefer strict ordinality (not allowing equal ranking).
 
-Voters may find the Range Ballot to be more complex than the Ranked Choices Ballot.
+Voters may find the Range Ballot to be more complex than the Ranked Choice Ballot.
 
 
 =head1 Objective and Motivation
@@ -444,7 +460,7 @@ When logging from your methods, use logt for events that produce a summary, use
 
 =head3 Active Sets
 
-Active sets are typically represented as a Hash Reference where the keys represent the active choices, the values are ignored. The VoteCount Object contains an Active Set which can be Accessed or set via the ->Active() method. The ->GetActive and ->SetActive methods are preferred because they break the reference link between the object's copy and the external copy of the Active set.
+Active sets are typically represented as a Hash Reference where the keys represent the active choices and the value is true. The VoteCount Object contains an Active Set which can be Accessed or set via the ->Active() method. The ->GetActive and ->SetActive methods are preferred because they break the reference link between the object's copy and the external copy of the Active set.
 
 Most Components will take an argument for $activeset or default to the current Active set of the Vote::Count object, which will default to the Choices defined in the BallotSet.
 
@@ -465,6 +481,24 @@ Active: Set or Get Active Set as HashRef
 
 
 
+=item *
+
+ResetActive: Sets the Active Set to the full choices list of the BallotSet.
+
+
+
+=item *
+
+SetActive: Sets the Active Set to provided HashRef. Using the Active method may preserve a reference between the Active Set and the HashRef, SetActive will not. The values to the hashref should evaluate as True.
+
+
+
+=item *
+
+SetActiveFromArrayRef: Same as SetActive except it takes an ArrayRef of the choices to be set as Active.
+
+
+
 =item *
 
 BallotSet: Get BallotSet
@@ -489,6 +523,12 @@ VotesCast: Returns the number of votes cast.
 
 
 
+=item *
+
+VotesActive: Returns the number of non-exhausted ballots based on the current Active Set.
+
+
+
 =back
 
 
