@@ -11,13 +11,13 @@ use Moose::Role;
 
 no warnings 'experimental';
 
-our $VERSION='1.01';
+our $VERSION='1.02';
 
 =head1 NAME
 
 Vote::Count::Floor
 
-=head1 VERSION 1.01
+=head1 VERSION 1.02
 
 =cut
 
@@ -84,13 +84,13 @@ sub TCA( $self ) {
 
 =head1 Floor Rules
 
-In real elections it is common to have choices with very little support, the right to write-in and the obligation to count write-ins can produce a large number of these choices, with iterative dropping like IRV it can take many rounds which have to be logged into the election report to work through them. A Floor Rule sets a criteria to remove the superfluous choices early in a single operation. If you are implementing a Hand-Count compatible process having an aggressive Floor Rule can be a benefit.
+In real elections it is common to have choices with very little support, the right to write-in and the obligation to count write-ins can produce a large number of these choices, with iterative dropping like IRV it can take many rounds which have to be logged into the election report to work through them. A Floor Rule sets a criteria to remove the weakly supported choices early in a single operation. If you are implementing a Hand-Count compatible process having an aggressive Floor Rule can be a benefit.
 
 =head1 SYNOPSIS
 
   my $Election = Vote::Count->new( BallotSet => $someballotset );
   my $ChoicesAfterFloor = $Election->ApprovalFloor();
-  $Election->Active( $ChoicesAfterFloor );
+  $Election->Active( $ChoicesAfterFloor ); # To apply the floor
 
 =head1 The Floor Methods
 
@@ -120,7 +120,7 @@ This rule takes no optional arguments.
 
 If there is a Loop or Condorcet Winner, either it will be/include the Top Count Leader or it must be a choice which defeats the Top Count leader. To defeat the Top Count Leader a Choice's Approval must be greater than the Lead Top Count. To be able to defeat a choice it is necessary to have more than half of the approval of that choice. Thus to be able to defeat a choice which can defeat the Top Count Leader it will be necessary to have more than half of the Approval of a choice with an Approval greater than the lead Top Count.
 
-There is a small possibility for a situation with a deeply nested Knotted result that this rule could eliminate a member of the Dominant Set. It can also be established for the common simple dropping rules (Approval, Top Count, Greatest Loss, Borda) that this choice would never win.
+There is a small possibility for a situation with a deeply nested knotted result that this rule could eliminate a member of the Dominant Set. For the common simple dropping rules (Approval, Top Count, Greatest Loss, Borda)  this choice would never win.
 
 For IRV any choice with an Approval that is not greater than the current TopCount of any other choice will always be eliminated prior to that choice. Unfortunately, with IRV any change to dropping order can alter the result. If it is used in IRV the Election Rules must specify it. Also because it is a high Approval based Floor, it can be construed as adding a small risk of Later Harm violation. If the reason for choosing IRV was Later Harm, then the only safe floor is a TopCount floor.
 
